==> utn_fra-1.0.0.26-py3-none-any.whl: utn_fra/datasets/__init__.py <==
# Copyright (C) 2025 <UTN FRA>
#
# Author: Facundo Falcone <f.falcone@sistemas-utnfra.com.ar>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .utn_listas import (
    # Listas simples
    lista_alturas_heroes, lista_apodos_heroes, lista_generos_heroes,
    lista_identidades_heroes, lista_nombres_heroes, lista_poder_heroes,
    
    lista_alturas_heroes_small, lista_apodos_heroes_small,
    lista_generos_heroes_small, lista_identidades_heroes_small,
    lista_nombres_heroes_small, lista_poder_heroes_small,
    
    lista_poke_ids, lista_poke_nombres, lista_poke_poderes,
    lista_poke_tipos, lista_poke_condiciones,
    
    lista_autos_marcas, lista_autos_modelos, lista_autos_cantidades,
    lista_autos_precios, lista_autos_ganancias,
    
    # Matriz de listas
    matriz_data_heroes, matriz_data_heroes_small,
    
    # Matriz de Pokémons
    matriz_pokemones,
    
    # MAtriz de concesionaria automotriz
    matriz_concesionaria,
    
    # Lista de diccionarios compleja
    lista_diccionario_heroes, lista_diccionario_heroes_small,
    lista_diccionario_heroes_hard, lista_diccionario_heroes_hard_small,
    
    # Lista de diccionarios simple
    lista_dict_pokemones
)

==> utn_fra-1.0.0.30-py3-none-any.whl: utn_fra/datasets/__init__.py <==
# Copyright (C) 2025 <UTN FRA>
#
# Author: Facundo Falcone <f.falcone@sistemas-utnfra.com.ar>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .utn_listas import (
    # Listas simples
    lista_alturas_heroes, lista_apodos_heroes, lista_generos_heroes,
    lista_identidades_heroes, lista_nombres_heroes, lista_poder_heroes,
    
    lista_alturas_heroes_small, lista_apodos_heroes_small,
    lista_generos_heroes_small, lista_identidades_heroes_small,
    lista_nombres_heroes_small, lista_poder_heroes_small,
    
    lista_poke_ids, lista_poke_nombres, lista_poke_poderes,
    lista_poke_tipos, lista_poke_condiciones,
    
    lista_autos_marcas, lista_autos_modelos, lista_autos_cantidades,
    lista_autos_precios, lista_autos_ganancias,
    
    lista_nombres_videos, lista_vistas_videos, lista_duraciones_videos,
    lista_nombres_videos_small, lista_vistas_videos_small, lista_duraciones_videos_small,
    
    # Matriz de listas
    matriz_data_heroes, matriz_data_heroes_small,
    
    # Matriz de Pokémons
    matriz_pokemones,
    
    # Matriz de concesionaria automotriz
    matriz_concesionaria,
    
    # Matriz Paulina
    matriz_paulina, matriz_paulina_small,
    
    # Lista de diccionarios compleja
    lista_diccionario_heroes, lista_diccionario_heroes_small,
    lista_diccionario_heroes_hard, lista_diccionario_heroes_hard_small,
    
    # Lista de diccionarios simple
    lista_dict_pokemones
)
